import {
  Loader, Metadata, IEventParam, IDictionary, Http,
} from '@zeedhi/core';
import {
  Form, SelectMultiple, Date as ZdDate, LoadingService, DialogService, Button,
} from '@zeedhi/common';

export class Pme02601ExportacaoIntegracao {
  private appController = Loader.getInstance('AppController');
  
  private utilities = Loader.getInstance('Utilities');
  
  public get setFilterAgreg() {
    return [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
  }
  
  public filtraTpCard({ component }: IEventParam<SelectMultiple>) {
    const form: Form = Metadata.getInstance('formExportacaoIntegracao');
    // const centralOrigem = form.value.CENTRAL_ORIGEM;
    const grupoTpCard = form.value.CDGRUPTIPOCARD;
    const filter = [
      {
        name: 'P_CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'P_CDAGRUPTPCARD',
        operator: '=',
        value: grupoTpCard === null ? 'T' : grupoTpCard,
      },
    ];
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public setFilterService({ component }: IEventParam<SelectMultiple>) {
    const form: Form = Metadata.getInstance('formExportacaoIntegracao');
    const grupoTpCard = form.value.CDGRUPTIPOCARD;
    const tipoCard = Metadata.getInstance<SelectMultiple>('TPCARD').value;
    
    const conditions = [
      {
        name: 'P_LISTATPCARD',
        operator: '=',
        value: tipoCard.join('_') || null,
      },
      {
        name: 'P_TODOSTPCARD',
        operator: '=',
        value: tipoCard.length > 0 ? tipoCard.join('_') : 'T',
      },
      {
        name: 'P_CDGRUPTIPOCARD',
        operator: '=',
        value: grupoTpCard || null,
      },
      {
        name: 'P_TGRUPTIPOCARD',
        operator: '=',
        value: grupoTpCard !== null ? grupoTpCard : 'T',
      },
      {
        name: 'P_CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'P_CDGRUPSERV',
        operator: '=',
        value: form?.value?.GRUPOSERVICO?.CDGRUPSERV || '',
      },
      {
        name: 'P_TCDGRUPSERV',
        operator: '=',
        value: form?.value?.GRUPOSERVICO?.CDGRUPSERV
          ? form?.value?.GRUPOSERVICO?.CDGRUPSERV : 'T',
      },
    ];
    component.datasource.filter = conditions;
    component.datasource.get();
  }
  
  public clearDependentField({ component }: IDictionary) {
    // const grupTpCard: Select = Metadata.getInstance('CDGRUPTIPOCARD');
    const tpCard: SelectMultiple = Metadata.getInstance('TPCARD');
    const servico: SelectMultiple = Metadata.getInstance('CDSERVFILI');

    if (component.name === 'CDGRUPTIPOCARD') {
      tpCard.setValue(null);
      servico.setValue(null);
    } else if (component.name === 'TPCARD' || component.name === 'GRUPOSERVICO') {
      servico.setValue(null);
    } else if (component.name === 'DTDE') {
      const finalDate: ZdDate = Metadata.getInstance('DTATE');
      finalDate.value = null;
    }
  }
  
  public confirmExport({ component }: IEventParam<Button>) {
    DialogService.show({
      name: `confirm-${component.name}`,
      type: 'warning',
      title: 'Atenção',
      text: component.name === 'cardapio' ? 'pme::desejaExportarCardapio' : 'pme::desejaExportarServico',
      buttons: [
        {
          name: 'yes',
          component: 'ZdButton',
          label: 'Sim',
          events: { click: () => this.executeExport(component.name) },
          outline: true,
        },
        {
          name: 'no',
          component: 'ZdButton',
          label: 'Não',
          events: { click: () => DialogService.hide() },
        },
      ],
    });
  }
  
  private executeExport(action: string) {
    const form: Form = Metadata.getInstance('formExportacaoIntegracao');
    // const row = { ...form.value };
    const row: IDictionary = {
      action,
      CDFILCENTPME: this.appController.getCdCentral(),
      CDGRUPTIPOCARD: form.value.CDGRUPTIPOCARD ? form.value.CDGRUPTIPOCARD : 'T',
      CDSERVFILI: form.value.CDSERVFILI.length > 0 ? form.value.CDSERVFILI.join('_') : 'T',
      CDGRUPSERV: form.value.GRUPOSERVICO ? form.value.GRUPOSERVICO.CDGRUPSERV : 'T',
      CDTIPOCARD: form.value.TPCARD.length > 0 ? form.value.TPCARD.join('_') : 'T',
      CDFILIAL: form.value.UNIDADE.length > 0 ? form.value.UNIDADE.join('_') : 'T',
      DTDE: form.value.DTDE,
      DTATE: form.value.DTATE,
    };
    LoadingService.show(' ');
    Http.post('/exportIntegrationTxt', { requestType: 'Row', row }).then((response: IDictionary) => {
      if (response?.data?.dataset?.export?.content && response?.data?.dataset?.export?.content !== '') {
        const a = document.createElement('a');
        document.body.appendChild(a);
        a.setAttribute('style', 'display: none');
        a.href = `data:application/octet-stream;base64,${response.data.dataset.export.content}`;
        a.download = `${row.action}.txt`;
        a.click();
        this.utilities.showAlert('plateSaved', 'pme::exportadoComSucesso', 'success');
      } else this.utilities.showAlert('alert', 'pme::naoEncontradoDadosExportar', 'warning');
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    }).finally(() => {
      DialogService.hide();
      LoadingService.hide();
    });
  }
}
